@@ -2,7 +2,9 @@ from multisite import SiteID
 
 from .defaults import *  # noqa
 
-print(f"Settings file {__file__}")  # noqa
+style = color_style()  # noqa: F405
+
+sys.stdout.write(style.MIGRATE_HEADING(f"Settings file {__file__}\n"))  # noqa: F405
 
 SITE_ID = SiteID(default=1)
 EDC_SITES_UAT_DOMAIN = True
