@@ -18,7 +18,7 @@ class BloodCulture(BloodCultureModelMixin, CrfModelMixin, edc_models.BaseUuidMod
         help_text="Start typing the requisition identifier or select one from this visit",
     )
 
-    comment = models.TextField(verbose_name="Any additional comment", blank=True)
+    comment = models.TextField(verbose_name="Any additional comment", blank=True, default="")
 
     class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
         verbose_name = "Blood Culture"
