@@ -29,9 +29,10 @@ class ChestXray(CrfModelMixin, edc_models.BaseUuidModel):
     chest_xray_results_other = models.TextField(
         verbose_name="If other, please specify ...",
         blank=True,
+        default="",
     )
 
-    comment = models.TextField(verbose_name="Any additional comment", blank=True)
+    comment = models.TextField(verbose_name="Any additional comment", blank=True, default="")
 
     class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
         verbose_name = "Chest X-ray"
